/*
 * Automatically generated C config: don't edit
 */
#define AUTOCONF_INCLUDED

/*
 * Code maturity level options
 */
#define CONFIG_EXPERIMENTAL 1

/*
 * Loadable module support
 */
#define CONFIG_MODULES 1
#undef  CONFIG_MODVERSIONS
#define CONFIG_KERNELD 1

/*
 * General setup
 */
#define CONFIG_MATH_EMULATION 1
#define CONFIG_NET 1
#undef  CONFIG_MAX_16M
#define CONFIG_PCI 1
#undef  CONFIG_PCI_OPTIMIZE
#define CONFIG_SYSVIPC 1
#define CONFIG_BINFMT_AOUT 1
#define CONFIG_BINFMT_ELF 1
#define CONFIG_BINFMT_JAVA 1
#define CONFIG_KERNEL_ELF 1
#define CONFIG_M386 1
#undef  CONFIG_M486
#undef  CONFIG_M586
#undef  CONFIG_M686

/*
 * Floppy, IDE, and other block devices
 */
#define CONFIG_BLK_DEV_FD 1
#define CONFIG_BLK_DEV_IDE 1

/*
 * Please see Documentation/ide.txt for help/info on IDE drives
 */
#undef  CONFIG_BLK_DEV_HD_IDE
#define CONFIG_BLK_DEV_IDECD 1
#define CONFIG_BLK_DEV_IDETAPE 1
#define CONFIG_BLK_DEV_IDE_PCMCIA 1
#define CONFIG_BLK_DEV_CMD640 1
#undef  CONFIG_BLK_DEV_CMD640_ENHANCED
#define CONFIG_BLK_DEV_RZ1000 1
#define CONFIG_BLK_DEV_TRITON 1
#undef  CONFIG_IDE_CHIPSETS

/*
 * Additional Block Devices
 */
#undef  CONFIG_BLK_DEV_LOOP
#define CONFIG_BLK_DEV_LOOP_MODULE 1
#define CONFIG_BLK_DEV_MD 1
#undef  CONFIG_MD_LINEAR
#define CONFIG_MD_LINEAR_MODULE 1
#undef  CONFIG_MD_STRIPED
#define CONFIG_MD_STRIPED_MODULE 1
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_BLK_DEV_INITRD 1
#undef  CONFIG_BLK_DEV_XD
#define CONFIG_BLK_DEV_XD_MODULE 1
#undef  CONFIG_BLK_DEV_HD

/*
 * Networking options
 */
#define CONFIG_FIREWALL 1
#undef  CONFIG_NET_ALIAS
#define CONFIG_INET 1
#define CONFIG_IP_FORWARD 1
#define CONFIG_IP_MULTICAST 1
#undef  CONFIG_SYN_COOKIES
#undef  CONFIG_RST_COOKIES
#define CONFIG_IP_FIREWALL 1
#undef  CONFIG_IP_FIREWALL_VERBOSE
#define CONFIG_IP_MASQUERADE 1

/*
 * Protocol-specific masquerading support will be built as modules.
 */
#define CONFIG_IP_MASQUERADE_IPAUTOFW 1
#define CONFIG_IP_MASQUERADE_ICMP 1
#undef  CONFIG_IP_TRANSPARENT_PROXY
#undef  CONFIG_IP_ALWAYS_DEFRAG
#undef  CONFIG_IP_ACCT
#undef  CONFIG_IP_ROUTER
#undef  CONFIG_NET_IPIP
#undef  CONFIG_IP_MROUTE

/*
 * (it is safe to leave these untouched)
 */
#undef  CONFIG_INET_PCTCP
#undef  CONFIG_INET_RARP
#define CONFIG_INET_RARP_MODULE 1
#undef  CONFIG_NO_PATH_MTU_DISCOVERY
#define CONFIG_IP_NOSR 1
#define CONFIG_SKB_LARGE 1

/*
 *  
 */
#undef  CONFIG_IPX
#define CONFIG_IPX_MODULE 1
#undef  CONFIG_IPX_INTERN
#undef  CONFIG_ATALK
#define CONFIG_ATALK_MODULE 1
#undef  CONFIG_AX25
#undef  CONFIG_BRIDGE
#undef  CONFIG_NETLINK

/*
 * SCSI support
 */
#define CONFIG_SCSI 1

/*
 * SCSI support type (disk, tape, CD-ROM)
 */
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_CHR_DEV_ST 1
#define CONFIG_BLK_DEV_SR 1
#define CONFIG_CHR_DEV_SG 1

/*
 * Some SCSI devices (e.g. CD jukebox) support multiple LUNs
 */
#undef  CONFIG_SCSI_MULTI_LUN
#define CONFIG_SCSI_CONSTANTS 1

/*
 * SCSI low-level drivers
 */
#undef  CONFIG_SCSI_7000FASST
#undef  CONFIG_SCSI_AHA152X
#undef  CONFIG_SCSI_AHA1542
#undef  CONFIG_SCSI_AHA1740
#undef  CONFIG_SCSI_AIC7XXX
#undef  CONFIG_SCSI_ADVANSYS
#undef  CONFIG_SCSI_IN2000
#undef  CONFIG_SCSI_AM53C974
#undef  CONFIG_SCSI_BUSLOGIC
#undef  CONFIG_SCSI_DTC3280
#undef  CONFIG_SCSI_EATA_DMA
#undef  CONFIG_SCSI_EATA_PIO
#undef  CONFIG_SCSI_EATA
#undef  CONFIG_SCSI_FUTURE_DOMAIN
#undef  CONFIG_SCSI_GENERIC_NCR5380
#undef  CONFIG_SCSI_NCR53C406A
#define CONFIG_SCSI_NCR53C7xx 1
#undef  CONFIG_SCSI_NCR53C7xx_sync
#undef  CONFIG_SCSI_NCR53C7xx_FAST
#undef  CONFIG_SCSI_NCR53C7xx_DISCONNECT
#undef  CONFIG_SCSI_PPA
#undef  CONFIG_SCSI_PAS16
#undef  CONFIG_SCSI_QLOGIC_FAS
#undef  CONFIG_SCSI_QLOGIC_ISP
#undef  CONFIG_SCSI_SEAGATE
#undef  CONFIG_SCSI_T128
#undef  CONFIG_SCSI_U14_34F
#undef  CONFIG_SCSI_ULTRASTOR

/*
 * Network device support
 */
#define CONFIG_NETDEVICES 1
#undef  CONFIG_DUMMY
#define CONFIG_DUMMY_MODULE 1
#undef  CONFIG_EQUALIZER
#define CONFIG_EQUALIZER_MODULE 1
#undef  CONFIG_DLCI
#define CONFIG_DLCI_MODULE 1
#define CONFIG_DLCI_COUNT (24)
#define CONFIG_DLCI_MAX (8)
#undef  CONFIG_SDLA
#define CONFIG_SDLA_MODULE 1
#undef  CONFIG_PLIP
#define CONFIG_PLIP_MODULE 1
#undef  CONFIG_PPP
#define CONFIG_PPP_MODULE 1

/*
 * CCP compressors for PPP are only built as modules.
 */
#undef  CONFIG_SLIP
#define CONFIG_SLIP_MODULE 1
#define CONFIG_SLIP_COMPRESSED 1
#undef  CONFIG_SLIP_SMART
#undef  CONFIG_SLIP_MODE_SLIP6
#undef  CONFIG_NET_RADIO
#define CONFIG_NET_ETHERNET 1
#undef  CONFIG_NET_VENDOR_3COM
#undef  CONFIG_LANCE
#define CONFIG_NET_VENDOR_SMC 1
#define CONFIG_WD80x3 1
#undef  CONFIG_ULTRA
#undef  CONFIG_SMC9194
#undef  CONFIG_NET_ISA
#undef  CONFIG_NET_EISA
#undef  CONFIG_NET_POCKET
#define CONFIG_TR 1
#undef  CONFIG_IBMTR
#define CONFIG_IBMTR_MODULE 1
#undef  CONFIG_FDDI
#undef  CONFIG_ARCNET

/*
 * ISDN subsystem
 */
#undef  CONFIG_ISDN
#define CONFIG_ISDN_MODULE 1
#undef  CONFIG_ISDN_PPP
#undef  CONFIG_ISDN_AUDIO
#undef  CONFIG_ISDN_DRV_ICN
#define CONFIG_ISDN_DRV_ICN_MODULE 1
#undef  CONFIG_ISDN_DRV_PCBIT
#define CONFIG_ISDN_DRV_PCBIT_MODULE 1
#undef  CONFIG_ISDN_DRV_TELES
#define CONFIG_ISDN_DRV_TELES_MODULE 1

/*
 * CD-ROM drivers (not for SCSI or IDE/ATAPI drives)
 */
#undef  CONFIG_CD_NO_IDESCSI

/*
 * Filesystems
 */
#define CONFIG_QUOTA 1
#define CONFIG_LOCK_MANDATORY 1
#define CONFIG_MINIX_FS 1
#undef  CONFIG_EXT_FS
#define CONFIG_EXT2_FS 1
#undef  CONFIG_XIA_FS
#define CONFIG_XIA_FS_MODULE 1
#define CONFIG_FAT_FS 1
#define CONFIG_MSDOS_FS 1
#define CONFIG_VFAT_FS 1
#define CONFIG_UMSDOS_FS 1
#define CONFIG_PROC_FS 1
#define CONFIG_NFS_FS 1
#undef  CONFIG_ROOT_NFS
#undef  CONFIG_SMB_FS
#define CONFIG_SMB_FS_MODULE 1
#define CONFIG_SMB_WIN95 1
#undef  CONFIG_NCP_FS
#define CONFIG_NCP_FS_MODULE 1
#define CONFIG_ISO9660_FS 1
#undef  CONFIG_HPFS_FS
#define CONFIG_HPFS_FS_MODULE 1
#undef  CONFIG_SYSV_FS
#define CONFIG_SYSV_FS_MODULE 1
#undef  CONFIG_AFFS_FS
#define CONFIG_AFFS_FS_MODULE 1
#define CONFIG_AMIGA_PARTITION 1
#undef  CONFIG_UFS_FS
#define CONFIG_UFS_FS_MODULE 1
#undef  CONFIG_BSD_DISKLABEL
#undef  CONFIG_SMD_DISKLABEL

/*
 * Character devices
 */
#define CONFIG_SERIAL 1
#undef  CONFIG_DIGI
#undef  CONFIG_CYCLADES
#define CONFIG_CYCLADES_MODULE 1
#undef  CONFIG_STALDRV
#undef  CONFIG_RISCOM8
#define CONFIG_RISCOM8_MODULE 1
#undef  CONFIG_PRINTER
#define CONFIG_PRINTER_MODULE 1
#define CONFIG_MOUSE 1
#undef  CONFIG_ATIXL_BUSMOUSE
#define CONFIG_ATIXL_BUSMOUSE_MODULE 1
#undef  CONFIG_BUSMOUSE
#define CONFIG_BUSMOUSE_MODULE 1
#undef  CONFIG_MS_BUSMOUSE
#define CONFIG_MS_BUSMOUSE_MODULE 1
#undef  CONFIG_PSMOUSE
#define CONFIG_PSMOUSE_MODULE 1
#define CONFIG_82C710_MOUSE 1
#undef  CONFIG_UMISC
#undef  CONFIG_QIC02_TAPE
#undef  CONFIG_FTAPE
#define CONFIG_FTAPE_MODULE 1

/*
 * Set IObase/IRQ/DMA for ftape in ./drivers/char/ftape/Makefile
 */
#undef  CONFIG_APM
#undef  CONFIG_WATCHDOG
#undef  CONFIG_RTC

/*
 * Sound
 */
#undef  CONFIG_SOUND

/*
 * Kernel hacking
 */
#undef  CONFIG_PROFILE
